pub struct LightDirectionSet(u8);Expand description
ScalableLux propagation direction bitset.
Tuple Fields
0: u8Implementations
Sourceimpl LightDirectionSet
impl LightDirectionSet
Sourcepub const fn from_raw(raw: u8) -> Self
pub const fn from_raw(raw: u8) -> Self
Creates a direction set from raw ScalableLux direction bits.
Sourcepub const fn only(direction: LightAxisDirection) -> Self
pub const fn only(direction: LightAxisDirection) -> Self
Creates a direction set containing exactly one axis direction.
Sourcepub const fn with(self, direction: LightAxisDirection) -> Self
pub const fn with(self, direction: LightAxisDirection) -> Self
Returns this set with one additional direction.
Sourcepub const fn all_except(direction: LightAxisDirection) -> Self
pub const fn all_except(direction: LightAxisDirection) -> Self
Creates a direction set containing all directions except one.
Sourcepub const fn all_except_opposite(direction: LightAxisDirection) -> Self
pub const fn all_except_opposite(direction: LightAxisDirection) -> Self
Creates a direction set containing all directions except the opposite of one direction.
Sourcepub const fn contains(self, direction: LightAxisDirection) -> bool
pub const fn contains(self, direction: LightAxisDirection) -> bool
Returns true when this set contains the selected axis direction.
Sourcepub const fn directions(self) -> LightDirectionSetIter ⓘ
pub const fn directions(self) -> LightDirectionSetIter ⓘ
Iterates selected directions in ScalableLux’s propagation order.